#!/bin/bash
# Root check
clear > /dev/null
echo -e "Determining root ..."
[ `whoami` = root ] || { sudo "$0" "$@"; exit $?; }

#Install Dependencies
echo -e "Installing Crossover package dependencies for 32 bit libraries."
yum -y install lshw pciutils redhat-lsb-core libv4l.i686 fontconfig.i686 libXcomposite.i686 libXinerama.i686 libgphoto2.i686 libxml2.i686 libxslt.i686 openldap.i686 sane-backends-libs.i686 mesa-dri-drivers.i686 isdn4k-utils.i686 gsm.i686 gstreamer-plugins-base.i686 lcms2.i686 mesa-libOSMesa.i686 libtiff.i686 gnutls.i686 > /dev/null

#Install Symlinks for TIFF and Mesa support
echo -e "Installing symlinks for TIFF and MESA support."
ln -s /usr/lib/libtiff.so.5.2.0 /usr/lib/libtiff.so.4 > /dev/null
ln -s /usr/lib/libOSMesa.so.8.0.0 /usr/lib/libOSMesa.so.6 > /dev/null

#Install CX
echo -e "Installing latest Crossover Linux RPM."
yum -y install http://crossover.codeweavers.com/redirect/crossover.rpm > /dev/null

#Tell the user to install their respective video drivers
echo -e "Updating PCI ID database."
update-pciids > /dev/null

#Retrieve display info
hw=`lshw -short -class Display`

#Set display search patterns
nvidia="(NVIDIA|GeForce|Quadro)"
amd="(AMD|ATI|FireGL|Radeon)"
intel="(Intel|INTEL)"

#Determine display manufacturer
nv_detected=`echo $hw | grep -ciE $nvidia`
amd_detected=`echo $hw | grep -ciE $amd`
intel_detected=`echo $hw | grep -ciE $intel`

echo nv $nv_detected
echo amd $amd_detected
echo intel $intel_detected

#Set OS search patterns
el="(RedHat|CentOS|Springdale|Scientific)"
fedora="(Fedora)"

#Determine LSB OS and release
lsb_os=`lsb_release -i`
lsb_release=`lsb_release -r`
lsb_el6="(6|6.1|6.2|6.3|6.4|6.5|6.6)"
lsb_el7="(7|7.1)"

#Determine OS and release
echo Determining OS and relase information
el_detected=`echo $lsb_os | grep -ciE $el`
el6_detected=`echo $lsb_release | grep -ciE $lsb_el6`
el7_detected=`echo $lsb_release | grep -ciE $lsb_el7`
fedora_detected=`echo $lsb_os | grep -ciE "$fedora"`

#NVIDIA test
if [ $nv_detected == 1 ]
  then 
    tput setaf 2 
    echo -e "NVIDIA graphics card found"
    tput sgr0
    echo -e "Determining OS..."
    if [ $el_detected == 1 ]
      then 
        echo -e "Enterprise Linux detected. Installing EPEL and ELRepo for drivers"
        rpm --import https://www.elrepo.org/RPM-GPG-KEY-elrepo.org > /dev/null
      if [ $el6_detected == 1 ]
        then
          yum -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-6.noarch.rpm > /dev/null
          yum -y install http://www.elrepo.org/elrepo-release-6-6.el6.elrepo.noarch.rpm > /dev/null
      fi
      if [ $el7_detected == 1 ]
        then
          yum -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm > /dev/null
          yum -y install http://www.elrepo.org/elrepo-release-7.0-2.el7.elrepo.noarch.rpm > /dev/null
      fi
      #Install nvidia-detect and install proper kmod, proper xorg bits, proper 32bit xorg bits and nuke off x11-glamor as it is incompatible with the nvidia driver.
      yum -y install nvidia-detect > /dev/null
      yum -y install `nvidia-detect` nvidia-x11-drv nvidia-x11-drv-32bit > /dev/null
      echo -e "As part of the NVIDIA driver installation you must take care of glamorgl, in this case we are removing it.  If you wish to keep it, and instead disable it, say NO to the install below."
      read -p "Press Enter or Return to continue with the process and choose to remove the packages or not." "mainmenuinput"
      yum remove xorg-x11-glamor
  fi
  
  if [ $fedora_detected == 1 ]
    then
      echo -e "Fedora Linux detected.  For driver installation process, please visit http://rpmfusion.org/Howto/nVidia for more information."
  fi     
fi

#AMD test
if [ $amd_detected == 1 ]
  then 
    tput setaf 1
    echo -e "AMD graphics card found.\n\nThis installer is not smart enough to know how to install drivers for your device."
    echo -e "Anaconda and Xorg should be using the Radeon driver.  If your card is supported in the Catalyst proprietary driver, you would be advised to look into that."
    echo -e "\nFor EL Installs :"
    echo -e "http://elrepo.org/tiki/kmod-fglrx or" 
    echo -e "http://elrepo.org/tiki/kmod-fglrx-legacy"
    echo -e "for installation instructions."
    echo -e "\nFedora is currently not supported at the time the script is written, and you are best served with the Radeon driver."
    echo -e "Sorry for any inconvenience."
    tput sgr0
fi

#Intel test
if [ $intel_detected == 1 ]
  then 
    tput setaf 4
    echo 'Intel graphics card found.  No drivers needed as of the time of writing of this script.'
    tput sgr0
fi
